==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/customercontractsalesprice_001/CustomerContractSalesPrice.java <==

package net.datastream.schemas.mp_entities.customercontractsalesprice_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CURRENCYID_Type;
import net.datastream.schemas.mp_fields.CUSTOMERCONTRACTSALESPRICEID_Type;
import net.datastream.schemas.mp_fields.ENTITYCODEID_Type;
import net.datastream.schemas.mp_fields.ENTITYID_Type;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.USERCONTRACTID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERCONTRACTSALESPRICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCONTRACTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYCODEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SALESPRICE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGCURRENCY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEEFFECTIVE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEEXPIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customercontractsalespriceid",
    "usercontractid",
    "entityid",
    "entitycodeid",
    "organizationid",
    "storeid",
    "salesprice",
    "orgcurrency",
    "dateeffective",
    "dateexpired",
    "partconditiontemplateconditioncode",
    "standardUserDefinedFields"
})
@XmlRootElement(name = "CustomerContractSalesPrice")
public class CustomerContractSalesPrice {

    @XmlElement(name = "CUSTOMERCONTRACTSALESPRICEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CUSTOMERCONTRACTSALESPRICEID_Type customercontractsalespriceid;
    @XmlElement(name = "USERCONTRACTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERCONTRACTID_Type usercontractid;
    @XmlElement(name = "ENTITYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ENTITYID_Type entityid;
    @XmlElement(name = "ENTITYCODEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ENTITYCODEID_Type entitycodeid;
    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "SALESPRICE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT salesprice;
    @XmlElement(name = "ORGCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type orgcurrency;
    @XmlElement(name = "DATEEFFECTIVE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME dateeffective;
    @XmlElement(name = "DATEEXPIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dateexpired;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété customercontractsalespriceid.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERCONTRACTSALESPRICEID_Type }
     *     
     */
    public CUSTOMERCONTRACTSALESPRICEID_Type getCUSTOMERCONTRACTSALESPRICEID() {
        return customercontractsalespriceid;
    }

    /**
     * Définit la valeur de la propriété customercontractsalespriceid.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERCONTRACTSALESPRICEID_Type }
     *     
     */
    public void setCUSTOMERCONTRACTSALESPRICEID(CUSTOMERCONTRACTSALESPRICEID_Type value) {
        this.customercontractsalespriceid = value;
    }

    /**
     * Obtient la valeur de la propriété usercontractid.
     * 
     * @return
     *     possible object is
     *     {@link USERCONTRACTID_Type }
     *     
     */
    public USERCONTRACTID_Type getUSERCONTRACTID() {
        return usercontractid;
    }

    /**
     * Définit la valeur de la propriété usercontractid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERCONTRACTID_Type }
     *     
     */
    public void setUSERCONTRACTID(USERCONTRACTID_Type value) {
        this.usercontractid = value;
    }

    /**
     * Obtient la valeur de la propriété entityid.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYID_Type }
     *     
     */
    public ENTITYID_Type getENTITYID() {
        return entityid;
    }

    /**
     * Définit la valeur de la propriété entityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYID_Type }
     *     
     */
    public void setENTITYID(ENTITYID_Type value) {
        this.entityid = value;
    }

    /**
     * Obtient la valeur de la propriété entitycodeid.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYCODEID_Type }
     *     
     */
    public ENTITYCODEID_Type getENTITYCODEID() {
        return entitycodeid;
    }

    /**
     * Définit la valeur de la propriété entitycodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYCODEID_Type }
     *     
     */
    public void setENTITYCODEID(ENTITYCODEID_Type value) {
        this.entitycodeid = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété salesprice.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getSALESPRICE() {
        return salesprice;
    }

    /**
     * Définit la valeur de la propriété salesprice.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setSALESPRICE(AMOUNT value) {
        this.salesprice = value;
    }

    /**
     * Obtient la valeur de la propriété orgcurrency.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getORGCURRENCY() {
        return orgcurrency;
    }

    /**
     * Définit la valeur de la propriété orgcurrency.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setORGCURRENCY(CURRENCYID_Type value) {
        this.orgcurrency = value;
    }

    /**
     * Obtient la valeur de la propriété dateeffective.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEEFFECTIVE() {
        return dateeffective;
    }

    /**
     * Définit la valeur de la propriété dateeffective.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEEFFECTIVE(DATETIME value) {
        this.dateeffective = value;
    }

    /**
     * Obtient la valeur de la propriété dateexpired.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEEXPIRED() {
        return dateexpired;
    }

    /**
     * Définit la valeur de la propriété dateexpired.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEEXPIRED(DATETIME value) {
        this.dateexpired = value;
    }

    /**
     * Obtient la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Définit la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Obtient la valeur de la propriété standardUserDefinedFields.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Définit la valeur de la propriété standardUserDefinedFields.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/customercontractsalesprice_001/CustomerContractSalesPrice.java <==

package net.datastream.schemas.mp_entities.customercontractsalesprice_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CURRENCYID_Type;
import net.datastream.schemas.mp_fields.CUSTOMERCONTRACTSALESPRICEID_Type;
import net.datastream.schemas.mp_fields.ENTITYCODEID_Type;
import net.datastream.schemas.mp_fields.ENTITYID_Type;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.USERCONTRACTID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERCONTRACTSALESPRICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCONTRACTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYCODEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SALESPRICE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGCURRENCY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEEFFECTIVE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEEXPIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customercontractsalespriceid",
    "usercontractid",
    "entityid",
    "entitycodeid",
    "organizationid",
    "storeid",
    "salesprice",
    "orgcurrency",
    "dateeffective",
    "dateexpired",
    "partconditiontemplateconditioncode",
    "standardUserDefinedFields"
})
@XmlRootElement(name = "CustomerContractSalesPrice")
public class CustomerContractSalesPrice {

    @XmlElement(name = "CUSTOMERCONTRACTSALESPRICEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CUSTOMERCONTRACTSALESPRICEID_Type customercontractsalespriceid;
    @XmlElement(name = "USERCONTRACTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERCONTRACTID_Type usercontractid;
    @XmlElement(name = "ENTITYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ENTITYID_Type entityid;
    @XmlElement(name = "ENTITYCODEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ENTITYCODEID_Type entitycodeid;
    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "SALESPRICE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT salesprice;
    @XmlElement(name = "ORGCURRENCY", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type orgcurrency;
    @XmlElement(name = "DATEEFFECTIVE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME dateeffective;
    @XmlElement(name = "DATEEXPIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dateexpired;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the customercontractsalespriceid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERCONTRACTSALESPRICEID_Type }
     *     
     */
    public CUSTOMERCONTRACTSALESPRICEID_Type getCUSTOMERCONTRACTSALESPRICEID() {
        return customercontractsalespriceid;
    }

    /**
     * Sets the value of the customercontractsalespriceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERCONTRACTSALESPRICEID_Type }
     *     
     */
    public void setCUSTOMERCONTRACTSALESPRICEID(CUSTOMERCONTRACTSALESPRICEID_Type value) {
        this.customercontractsalespriceid = value;
    }

    /**
     * Gets the value of the usercontractid property.
     * 
     * @return
     *     possible object is
     *     {@link USERCONTRACTID_Type }
     *     
     */
    public USERCONTRACTID_Type getUSERCONTRACTID() {
        return usercontractid;
    }

    /**
     * Sets the value of the usercontractid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERCONTRACTID_Type }
     *     
     */
    public void setUSERCONTRACTID(USERCONTRACTID_Type value) {
        this.usercontractid = value;
    }

    /**
     * Gets the value of the entityid property.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYID_Type }
     *     
     */
    public ENTITYID_Type getENTITYID() {
        return entityid;
    }

    /**
     * Sets the value of the entityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYID_Type }
     *     
     */
    public void setENTITYID(ENTITYID_Type value) {
        this.entityid = value;
    }

    /**
     * Gets the value of the entitycodeid property.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYCODEID_Type }
     *     
     */
    public ENTITYCODEID_Type getENTITYCODEID() {
        return entitycodeid;
    }

    /**
     * Sets the value of the entitycodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYCODEID_Type }
     *     
     */
    public void setENTITYCODEID(ENTITYCODEID_Type value) {
        this.entitycodeid = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the salesprice property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getSALESPRICE() {
        return salesprice;
    }

    /**
     * Sets the value of the salesprice property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setSALESPRICE(AMOUNT value) {
        this.salesprice = value;
    }

    /**
     * Gets the value of the orgcurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getORGCURRENCY() {
        return orgcurrency;
    }

    /**
     * Sets the value of the orgcurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setORGCURRENCY(CURRENCYID_Type value) {
        this.orgcurrency = value;
    }

    /**
     * Gets the value of the dateeffective property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEEFFECTIVE() {
        return dateeffective;
    }

    /**
     * Sets the value of the dateeffective property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEEFFECTIVE(DATETIME value) {
        this.dateeffective = value;
    }

    /**
     * Gets the value of the dateexpired property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEEXPIRED() {
        return dateexpired;
    }

    /**
     * Sets the value of the dateexpired property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEEXPIRED(DATETIME value) {
        this.dateexpired = value;
    }

    /**
     * Gets the value of the partconditiontemplateconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Sets the value of the partconditiontemplateconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
